AngularJS UI Tree demo

# Tree component

The AngularJS Tree component with drag and drop support.

Code on GitHub

## What?

Angular Tree is an AngularJS UI component that can sort nested lists, provides drag & drop support and doesn't depend on jQuery.

## Features

- Uses the native AngularJS scope for data binding
- Sorted and move items through the entire tree
- Prevent elements from accepting child nodes

## Examples

1. Unlimited nesting
2. Above with horizontal sorting
3. Connected trees
4. Groups & Categories
5. Filter

## See it in action

### Draggable Tree

### Full tree

    {{ list | json }}